@@ -1,14 +1,16 @@
 from collections import defaultdict
-from typing import Any, DefaultDict, List
+from typing import DefaultDict, List
 
-from Xlib.protocol.display import Screen
 from Xlib.X import ShiftMask
 
 from s3wm.layouts.default_tile.key_bindings import (
     change_gaps,
     change_tab,
+    change_window_size,
     kill_focused_window,
     move_focus,
+    move_window_backward,
+    move_window_forward,
     move_window_to_tab,
 )
 from s3wm.layouts.default_tile.tab import Tab
@@ -32,7 +34,7 @@ class DefaultTile(AbstractLayoutManager):
         """
         super().__init__(wm)
         self.tab_class.gaps = self.gaps
-        self.tabs: DefaultDict[int, Any] = defaultdict(self.tab_class)
+        self.tabs: DefaultDict[int, Tab] = defaultdict(self.tab_class)
         self.current_tab = 0
         self.tabs[self.current_tab].focus()
 
@@ -44,14 +46,6 @@ class DefaultTile(AbstractLayoutManager):
         """
         self.tabs[self.current_tab].add_window(window)
 
-    def update_layout(self, screen: Screen) -> None:
-        """
-        Update the whole layout layout.
-
-        :param screen: current screen.
-        """
-        self.tabs[self.current_tab].update_layout()
-
     def remove_window(self, window: S3window) -> None:
         """
         Remove window from current layout.
@@ -59,7 +53,6 @@ class DefaultTile(AbstractLayoutManager):
         :param window: removed window.
         """
         self.tabs[self.current_tab].remove_window(window)
-        self.update_layout(window.screen)
 
     def change_tab(self, tab_number: int) -> None:
         """
@@ -88,7 +81,8 @@ class DefaultTile(AbstractLayoutManager):
         :param tab_index: to which tab do we need to move.
         """
         window = self.tabs[self.current_tab].pop_focused_window()
-        self.tabs[tab_index].add_window(window)
+        if window:
+            self.tabs[tab_index].add_window(window)
 
     def kill_focused_window(self) -> None:
         """Kill focused window."""
@@ -96,6 +90,32 @@ class DefaultTile(AbstractLayoutManager):
         if window:
             window.destroy()
 
+    def change_gap_value(self, gap_delta: int) -> None:
+        """
+        Update gap value for tabs.
+
+        :param gap_delta: delta to current gap value.
+        """
+        self.tab_class.gaps = min(self.tab_class.gaps + gap_delta, 100)
+        self.tab_class.gaps = max(0, self.tab_class.gaps)
+        self.tabs[self.current_tab].update_layout()
+
+    def change_main_window_size(self, delta: int) -> None:
+        """
+        Change main window size.
+
+        :param delta: size delta.
+        """
+        self.tabs[self.current_tab].change_main_window_size(delta)
+
+    def move_window_forward(self) -> None:
+        """Move currently focused window forward."""
+        self.tabs[self.current_tab].move_window_forward()
+
+    def move_window_backward(self) -> None:
+        """Move currently focused window backward."""
+        self.tabs[self.current_tab].move_window_backward()
+
     @classmethod
     def get_keys(cls) -> List[KeyCombination]:
         """Get Keys specific to your layout.
@@ -134,6 +154,16 @@ class DefaultTile(AbstractLayoutManager):
                     key="k",
                     action=move_focus(prev=True),
                 ),
+                KeyCombination(
+                    modifiers=KeyCombination.default_mod_key | ShiftMask,
+                    key="j",
+                    action=move_window_backward,
+                ),
+                KeyCombination(
+                    modifiers=KeyCombination.default_mod_key | ShiftMask,
+                    key="k",
+                    action=move_window_forward,
+                ),
                 KeyCombination(
                     modifiers=KeyCombination.default_mod_key | ShiftMask,
                     key="c",
@@ -149,6 +179,16 @@ class DefaultTile(AbstractLayoutManager):
                     key="plus",
                     action=change_gaps(2),
                 ),
+                KeyCombination(
+                    modifiers=KeyCombination.default_mod_key,
+                    key="h",
+                    action=change_window_size(-5),
+                ),
+                KeyCombination(
+                    modifiers=KeyCombination.default_mod_key,
+                    key="l",
+                    action=change_window_size(5),
+                ),
             ],
         )
 
